# MessageSendRequest

Requests that the system send one or more messages, using the messages' properties and the provided addresses in conjunction with the users' configuration to determine how it is routed. 

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**messages** | [**[MessageSendItem]**](MessageSendItem.md) | The messages to send | 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


